UnicalTaskState class abstract

Canonical task state kept server-side so a user's devices stay in sync (percent/tags live here, not just on one device).

Constructors

UnicalTaskState({int? id, required int accountId, UnicalCalendarAccount? account, required String localId, required String title, required int percent, required List<String> tags, DateTime? due, required String status, required DateTime updatedAt})
factory
UnicalTaskState.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

account UnicalCalendarAccount?
getter/setter pair
accountId int
getter/setter pair
due DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pair
localId String
getter/setter pair
percent int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
table → Table<int?>
The table that this row belongs to.
no setter
tags List<String>
getter/setter pair
title String
getter/setter pair
updatedAt DateTime
getter/setter pair

Methods

copyWith({int? id, int? accountId, UnicalCalendarAccount? account, String? localId, String? title, int? percent, List<String>? tags, DateTime? due, String? status, DateTime? updatedAt}) UnicalTaskState
Returns a shallow copy of this UnicalTaskState with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

t UnicalTaskStateTable
final

Static Methods

include({UnicalCalendarAccountInclude? account}) UnicalTaskStateInclude
includeList({WhereExpressionBuilder<UnicalTaskStateTable>? where, int? limit, int? offset, OrderByBuilder<UnicalTaskStateTable>? orderBy, bool orderDescending = false, OrderByListBuilder<UnicalTaskStateTable>? orderByList, UnicalTaskStateInclude? include}) UnicalTaskStateIncludeList

Constants

db → const UnicalTaskStateRepository